# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from logit import logit

from intro.models import IntroCategoryInfo, IntroContentInfo, IntroNameInfo
from utils.error.errno_utils import IntroStatusCode
from utils.error.response_utils import response


@logit
def intro_list_api(request):
    cates = IntroCategoryInfo.objects.filter(status=True).order_by('position')
    cates = [cate.data for cate in cates]

    return response(200, 'Get Intro List Success', u'获取说明书列表成功', {
        'cates': cates,
    })


@logit
def intro_name_info_api(request):
    pk = int(request.POST.get('pk', 0))

    try:
        name = IntroNameInfo.objects.get(pk=pk)
    except IntroNameInfo.DoesNotExist:
        return response(IntroStatusCode.INTRO_NAME_NOT_FOUND)

    return response(200, 'Get Intro Name Info Success', u'获取说明书信息成功', {
        'name': name.data,
    })


@logit
def intro_query_api(request):
    query = request.POST.get('query', '')

    cates = IntroContentInfo.objects.filter(content__contains=query, status=True).order_by('position')
    cates = [cate.data2 for cate in cates]

    return response(200, 'Intro Query Success', u'说明书检索成功', {
        'cates': cates,
    })
